diff --git a/src/backend/replication/logical/worker.c b/src/backend/replication/logical/worker.c
index f3868b3e1f..f7f77071c5 100644
--- a/src/backend/replication/logical/worker.c
+++ b/src/backend/replication/logical/worker.c
@@ -3898,7 +3898,13 @@ maybe_start_skipping_changes(XLogRecPtr finish_lsn)
 	 */
 	if (likely(XLogRecPtrIsInvalid(MySubscription->skiplsn) ||
 			   MySubscription->skiplsn != finish_lsn))
+	{
+		ereport(LOG,
+				(errmsg("not started skipping changes: my_skiplsn %X/%X finish_lsn %X/%X",
+						LSN_FORMAT_ARGS(MySubscription->skiplsn),
+						LSN_FORMAT_ARGS(finish_lsn))));
 		return;
+	}
 
 	/* Start skipping all changes of this transaction */
 	skip_xact_finish_lsn = finish_lsn;
@@ -3969,6 +3975,12 @@ clear_subscription_skip_lsn(XLogRecPtr finish_lsn)
 
 	subform = (Form_pg_subscription) GETSTRUCT(tup);
 
+	ereport(LOG,
+			(errmsg("clear subskiplsn %X/%X mysubskiplsn %X/%X finish_lsn %X/%X",
+					LSN_FORMAT_ARGS(subform->subskiplsn),
+					LSN_FORMAT_ARGS(myskiplsn),
+					LSN_FORMAT_ARGS(finish_lsn))));
+
 	/*
 	 * Clear the subskiplsn. If the user has already changed subskiplsn before
 	 * clearing it we don't update the catalog and the replication origin
